"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.disableNetConnect = exports.getApiFixture = exports.getConfigFixture = exports.encodeContent = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const js_yaml_1 = __importDefault(require("js-yaml"));
exports.encodeContent = (content) => Buffer.from(content).toString('base64');
// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.getConfigFixture = (rootDir, fileName = 'config.yml') => ({
    type: 'file',
    encoding: 'base64',
    size: 5362,
    name: fileName,
    path: `.github/${fileName}`,
    content: exports.encodeContent(fs_1.default.readFileSync(path_1.default.resolve(rootDir, fileName)).toString()),
    sha: '3d21ec53a331a6f037a91c368710b99387d012c1',
    url: 'https://api.github.com/repos/Codertocat/Hello-World/contents/.github/release-drafter.yml',
    'git_url': 'https://api.github.com/repos/Codertocat/Hello-World/git/blobs/3d21ec53a331a6f037a91c368710b99387d012c1',
    'html_url': 'https://github.com/Codertocat/Hello-World/blob/master/.github/release-drafter.yml',
    'download_url': 'https://raw.githubusercontent.com/Codertocat/Hello-World/master/.github/release-drafter.yml',
    _links: {
        git: 'https://api.github.com/repos/Codertocat/Hello-World/git/blobs/3d21ec53a331a6f037a91c368710b99387d012c1',
        self: 'https://api.github.com/repos/Codertocat/Hello-World/contents/.github/release-drafter.yml',
        html: 'https://github.com/Codertocat/Hello-World/blob/master/.github/release-drafter.yml',
    },
});
// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.getApiFixture = (rootDir, name, ext = '.json') => {
    const content = fs_1.default.readFileSync(path_1.default.resolve(rootDir, `${name}${ext}`)).toString();
    switch (ext.toLowerCase()) {
        case '.json':
            return JSON.parse(content);
        case '.yml':
        case '.yaml':
            return js_yaml_1.default.safeLoad(content) || {};
        default:
            return { content };
    }
};
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
exports.disableNetConnect = (nock) => {
    beforeEach(() => {
        nock.disableNetConnect();
    });
    afterEach(() => {
        nock.cleanAll();
        nock.enableNetConnect();
    });
};
